package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;

public class AuthorityInformationAccess extends ASN1Encodable {
   private AccessDescription[] descriptions;

   public static AuthorityInformationAccess getInstance(Object obj) {
      if (obj instanceof AuthorityInformationAccess) {
         return (AuthorityInformationAccess)obj;
      } else if (obj instanceof ASN1Sequence) {
         return new AuthorityInformationAccess((ASN1Sequence)obj);
      } else if (obj instanceof X509Extension) {
         return getInstance(X509Extension.convertValueToObject((X509Extension)obj));
      } else {
         throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
      }
   }

   public AuthorityInformationAccess(ASN1Sequence seq) {
      this.descriptions = new AccessDescription[seq.size()];

      for(int var2 = 0; var2 != seq.size(); ++var2) {
         this.descriptions[var2] = AccessDescription.getInstance(seq.getObjectAt(var2));
      }

   }

   public AuthorityInformationAccess(DERObjectIdentifier oid, GeneralName location) {
      AccessDescription[] var10000 = this.descriptions = new AccessDescription[1];
      AccessDescription var3;
      var3 = new AccessDescription.<init>(oid, location);
      var10000[0] = var3;
   }

   public AccessDescription[] getAccessDescriptions() {
      return this.descriptions;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();

      AccessDescription[] var3;
      for(int var2 = 0; var2 != (var3 = this.descriptions).length; ++var2) {
         var1.add(var3[var2]);
      }

      return new DERSequence(var1);
   }

   public String toString() {
      return "AuthorityInformationAccess: Oid(" + this.descriptions[0].getAccessMethod().getId() + ")";
   }
}
